Sound Field Synthesis (SFS) Toolbox for Python
==============================================

A Python library for creating numercial simulations of sound field synthesis
methods like Wave Field Synthesis (WFS) or Near-Field Compensated Higher Order
Ambisonics (NFC-HOA).

Documentation:
    https://sfs-python.readthedocs.io/

Source code and issue tracker:
    https://github.com/sfstoolbox/sfs-python/

License:
    MIT -- see the file ``LICENSE`` for details.

Quick start:
    * Install Python 3, NumPy, SciPy and Matplotlib
    * ``python3 -m pip install sfs --user``
    * Check out the examples in the documentation

More information about the underlying theory can be found at
https://sfs.readthedocs.io/.
There is also a Sound Field Synthesis Toolbox for Octave/Matlab, see
https://sfs-matlab.readthedocs.io/.
